==> haskell-hjsonpointer-1.4.0-38-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hjsonpointer.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsonpointer
version: 1.4.0
id: hjsonpointer-1.4.0-DUcwTHUiqW6EhyqLSthDdy
key: hjsonpointer-1.4.0-DUcwTHUiqW6EhyqLSthDdy
license: MIT
maintainer: ian@housejeffries.com
author: Ian Grant Jeffries
homepage: https://github.com/seagreen/hjsonpointer
synopsis: JSON Pointer library
category: Data
abi: 17414f4479783005f8e8e81a60b5924c
exposed: True
exposed-modules:
    JSONPointer
import-dirs: /usr/lib/ghc-8.4.3/site-local/hjsonpointer-1.4.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hjsonpointer-1.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hjsonpointer-1.4.0
hs-libraries: HShjsonpointer-1.4.0-DUcwTHUiqW6EhyqLSthDdy
depends:
    base-4.11.1.0 aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre text-1.2.3.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX=25adaf2f506e44c8d5bd8da34f9279d5
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-hjsonpointer/html/hjsonpointer.haddock
haddock-html: /usr/share/doc/haskell-hjsonpointer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hjsonpointer-1.4.0-39-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hjsonpointer.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsonpointer
version: 1.4.0
id: hjsonpointer-1.4.0-LZy1MYr2PQR5oSWL3KSjBx
key: hjsonpointer-1.4.0-LZy1MYr2PQR5oSWL3KSjBx
license: MIT
maintainer: ian@housejeffries.com
author: Ian Grant Jeffries
homepage: https://github.com/seagreen/hjsonpointer
synopsis: JSON Pointer library
category: Data
abi: 337ae25815a2053ccfd01c62b03f0ddf
exposed: True
exposed-modules:
    JSONPointer
import-dirs: /usr/lib/ghc-8.4.3/site-local/hjsonpointer-1.4.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hjsonpointer-1.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hjsonpointer-1.4.0
hs-libraries: HShjsonpointer-1.4.0-LZy1MYr2PQR5oSWL3KSjBx
depends:
    base-4.11.1.0 aeson-1.4.1.0-FRlNztmBJkOGWbKGvmlaJP
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre text-1.2.3.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             aeson-1.4.1.0-FRlNztmBJkOGWbKGvmlaJP=5da4d30660c7a0118522c660d6f5af43
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-hjsonpointer/html/hjsonpointer.haddock
haddock-html: /usr/share/doc/haskell-hjsonpointer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
